@@ -147,8 +147,8 @@ namespace DynS
 		Eigen::Vector3ld intersectionPoint;
 		int prevsign;
 		int sign;
-		point = trajectory[0];
-		prevsign = SideSign(planeEquation, point);
+		prevpoint = trajectory[0];
+		prevsign = SideSign(planeEquation, prevpoint);
 
 		int N = trajectory.size();
 		for (int i = 1; i < N; i++) {
